@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002, 2015 Jens Keiner, Stefan Kunis, Daniel Potts
+ * Copyright (c) 2002, 2016 Jens Keiner, Stefan Kunis, Daniel Potts
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free Software
@@ -16,8 +16,6 @@
  * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-/* $Id: simple_test.c 3509 2010-05-25 19:00:59Z keiner $ */
-
 /* Standard headers. */
 #include <stdio.h>
 #include <stdlib.h>
@@ -235,7 +233,7 @@ static R err_trafo(X(plan) *p)
     a = K(0.4);
     b = K(2000.0);
 #else
-    a = K(0.4);
+    a = K(0.41);
     b = K(50.0);
 #endif
     err = EXP(-m*KPI*(K(1.0)-K(1.0)/(K(2.0)*K(2.0) - K(1.0))));
@@ -414,7 +412,7 @@ static void setup_file(const testcase_delegate_t *ego_, int *d, int **N, int *NN
   printf(" M = %-5d", *M);
 
 #ifdef _OPENMP
-  printf(" nthreads = %td", X(get_num_threads)());
+  printf(" nthreads = " __D__, X(get_num_threads)());
 #endif
 
   for (j = 0, *NN = 1; j < *d; j++)
@@ -487,7 +485,7 @@ static void setup_online(const testcase_delegate_t *ego_, int *d, int **N, int *
   printf(" M = %-5d", *M);
 
 #ifdef _OPENMP
-  printf(" nthreads = %td", X(get_num_threads)());
+  printf(" nthreads = " __D__, X(get_num_threads)());
 #endif
 
   for (j = 0, *NN = 1; j < *d; j++)
@@ -575,7 +573,7 @@ static void setup_adjoint_online(const testcase_delegate_t *ego_, int *d, int **
   printf(" M = %-5d", *M);
 
 #ifdef _OPENMP
-  printf(" nthreads = %td", X(get_num_threads)());
+  printf(" nthreads = " __D__, X(get_num_threads)());
 #endif
 
   for (j = 0, *NN = 1; j < *d; j++)
@@ -980,10 +978,12 @@ static const testcase_delegate_online_t *testcases_1d_online[] =
   &nfft_online_1d_100_50,
   &nfft_online_1d_200_50,
   &nfft_online_1d_500_50,
+#ifdef NFFT_EXHAUSTIVE_UNIT_TESTS
   &nfft_online_1d_1000_50,
   &nfft_online_1d_2000_50,
   &nfft_online_1d_5000_50,
   &nfft_online_1d_10000_50,
+#endif
 };
 
 static const trafo_delegate_t* trafos_1d_online[] = {&trafo, &trafo_1d};
@@ -1009,10 +1009,12 @@ static const testcase_delegate_online_t *testcases_adjoint_1d_online[] =
   &nfft_adjoint_online_1d_100_50,
   &nfft_adjoint_online_1d_200_50,
   &nfft_adjoint_online_1d_500_50,
+#ifdef NFFT_EXHAUSTIVE_UNIT_TESTS
   &nfft_adjoint_online_1d_1000_50,
   &nfft_adjoint_online_1d_2000_50,
   &nfft_adjoint_online_1d_5000_50,
   &nfft_adjoint_online_1d_10000_50,
+#endif
 };
 
 static const trafo_delegate_t* trafos_adjoint_1d_online[] = {&adjoint, &adjoint_1d};
@@ -1134,8 +1136,10 @@ static const testcase_delegate_online_t *testcases_2d_online[] =
   &nfft_online_2d_50_50,
   &nfft_online_2d_100_50,
   &nfft_online_2d_200_50,
+#ifdef NFFT_EXHAUSTIVE_UNIT_TESTS
   &nfft_online_2d_500_50,
   &nfft_online_2d_1000_50,
+#endif
 };
 
 static const trafo_delegate_t* trafos_2d_online[] = {&trafo, &trafo_2d};
@@ -1157,8 +1161,10 @@ static const testcase_delegate_online_t *testcases_adjoint_2d_online[] =
   &nfft_adjoint_online_2d_50_50,
   &nfft_adjoint_online_2d_100_50,
   &nfft_adjoint_online_2d_200_50,
+#ifdef NFFT_EXHAUSTIVE_UNIT_TESTS
   &nfft_adjoint_online_2d_500_50,
   &nfft_adjoint_online_2d_1000_50,
+#endif
 };
 
 static const trafo_delegate_t* trafos_adjoint_2d_online[] = {&adjoint, &adjoint_2d};
@@ -1241,6 +1247,7 @@ void X(check_adjoint_3d_fast_file)(void)
     testcases_adjoint_3d_file, initializers_3d, &check_adjoint, trafos_adjoint_3d_fast_file);
 }
 
+#ifdef NFFT_EXHAUSTIVE_UNIT_TESTS
 static const testcase_delegate_online_t nfft_online_3d_50_50 = {setup_online, destroy_online, 3, 50 ,50};
 
 static const testcase_delegate_online_t *testcases_3d_online[] =
@@ -1270,6 +1277,7 @@ void X(check_adjoint_3d_online)(void)
   check_many(SIZE(testcases_adjoint_3d_online), SIZE(initializers_3d), SIZE(trafos_adjoint_3d_online),
     testcases_adjoint_3d_online, initializers_3d, &check_adjoint, trafos_adjoint_3d_online);
 }
+#endif
 
 /* 4D. */
 
@@ -1292,6 +1300,7 @@ static const init_delegate_t* initializers_4d[] =
 #endif
 };
 
+#ifdef NFFT_EXHAUSTIVE_UNIT_TESTS
 static const testcase_delegate_online_t nfft_online_4d_28_50 = {setup_online, destroy_online, 4, 28 ,50};
 
 static const testcase_delegate_online_t *testcases_4d_online[] =
@@ -1321,6 +1330,7 @@ void X(check_adjoint_4d_online)(void)
   check_many(SIZE(testcases_adjoint_4d_online), SIZE(initializers_4d), SIZE(trafos_adjoint_4d_online),
     testcases_adjoint_4d_online, initializers_4d, &check_adjoint, trafos_adjoint_4d_online);
 }
+#endif
 
 /* accuracy */
 
